# Afori Utils

This package contains an aggregation of tools used by Dor Miron.
Afori is my cat, and he contributed some changes now and then.

## Installation

Run the following to install:

```python 
pip install afori_utils
```

## Usage

```python
from ignore.afori_utils import pyplot_utils, sync_utils
from afori_utils import debug_utils, sync_utils
```


